
package Paws::IoTJobsData::GetPendingJobExecutions;
  use Moose;
  has ThingName => (is => 'ro', isa => 'Str', traits => ['ParamInURI'], uri_name => 'thingName', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'GetPendingJobExecutions');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/things/{thingName}/jobs');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'GET');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::IoTJobsData::GetPendingJobExecutionsResponse');
1;

### main pod documentation begin ###

=head1 NAME

Paws::IoTJobsData::GetPendingJobExecutions - Arguments for method GetPendingJobExecutions on L<Paws::IoTJobsData>

=head1 DESCRIPTION

This class represents the parameters used for calling the method GetPendingJobExecutions on the
L<AWS IoT Jobs Data Plane|Paws::IoTJobsData> service. Use the attributes of this class
as arguments to method GetPendingJobExecutions.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to GetPendingJobExecutions.

=head1 SYNOPSIS

    my $data.jobs.iot = Paws->service('IoTJobsData');
    my $GetPendingJobExecutionsResponse =
      $data . jobs . iot->GetPendingJobExecutions(
      ThingName => 'MyThingName',

      );

    # Results:
    my $inProgressJobs = $GetPendingJobExecutionsResponse->inProgressJobs;
    my $queuedJobs     = $GetPendingJobExecutionsResponse->queuedJobs;

    # Returns a L<Paws::IoTJobsData::GetPendingJobExecutionsResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://aws.amazon.com/documentation/iot/>

=head1 ATTRIBUTES


=head2 B<REQUIRED> ThingName => Str

The name of the thing that is executing the job.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method GetPendingJobExecutions in L<Paws::IoTJobsData>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

